| http://www.onvif.org/federatedsearch/wsdl

Operations

Port type FederatedSearchPort

1. GetSearchResults

Description

Request the results of a previous query issued.
SOAP action:
http://www.onvif.org/federatedsearch/wsdl/GetSearchResults
Input:
[GetSearchResults]

■ Results [MpegQueryType]

Allows to request the results of a previous query issued.

[Choice]

■ Query[Choice]

■ FetchResult

◦ queryID [anyURI]

◦ retrievePageNum [positiveInteger]

◦ mpqfID required; [anyURI]

Output:

[GetSearchResultsResponse]

■ ResultItem optional, unbounded; [MpegQueryType]

Describes a single result returned from a responder.

[Choice]

■ Query[Choice]

■ Output [OutputQueryType]

■ GlobalComment optional; [string]

■ ResultItem optional, unbounded; [ResultItemType]

■ SystemMessage optional; [SystemMessageType][Choice]

■ Status unbounded; [InformationType]

■ Code [positiveInteger]

■ Description [string]

■ Warning unbounded; [InformationType]

■ Code [positiveInteger]

■ Description [string]

■ Exception unbounded; [InformationType]

■ Code [positiveInteger]

■ Description [string]

◦ currPage [positiveInteger]

◦ totalPages [positiveInteger]

◦ expirationDate optional; [dateTime]

◦ mpqfID required; [anyURI]

-----------------------------------------------------------------------------------------------------------------------------------------------

2. GetServiceCapabilities

Description:

Returns the capabilities of the federated search service. The result is returned in a typed answer.

SOAP action:

http://www.onvif.org/federatedsearch/wsdl/GetServiceCapabilities

Input:

[GetServiceCapabilities]

Output:

[GetServiceCapabilitiesResponse]

■ Capabilities [Capabilities]

-----------------------------------------------------------------------------------------------------------------------------------------------

3. GetServiceFeatures

Description

Returns the capabilities of the service matching any given capability.

SOAP action:

http://www.onvif.org/federatedsearch/wsdl/GetServiceFeatures

Input:

[GetServiceFeatures]

■ InputCapabilities [MpegQueryType]

Contains descriptions of desired services capabilities and may contain the ID for a particular service to be

addressed.

[Choice]

■ Query[Choice]

■ Management[Choice]

■ Input [InputManagementType]

■ DesiredCapability optional; [CapabilityType]

Elements used are as defined in ISO/IEC 1593812

■ SupportedQFProfile optional; [TermType]

■ Name optional; [string]

■ Description optional; [string]

■ Term optional, unbounded; [TermType]

■ Name optional; [string]

■ Description optional; [string]

■ Term optional, unbounded; [TermType]

■ Name optional; [string]

■ Description optional; [string]

■ Term optional, unbounded; [TermType] ... is recursive

◦ href required; [SimpleTermType]

◦ href required; [SimpleTermType]

◦ href required; [SimpleTermType]

■ SupportedMetadata optional, unbounded; [anyURI]

■ SupportedExampleMediaTypes optional;

■ SupportedResultMediaTypes optional;

■ SupportedQueryTypes optional, unbounded; [TermType]

■ Name optional; [string]

■ Description optional; [string]

■ Term optional, unbounded; [TermType]

■ Name optional; [string]

■ Description optional; [string]

■ Term optional, unbounded; [TermType]

■ Name optional; [string]

■ Description optional; [string]

■ Term optional, unbounded; [TermType] ... is recursive

◦ href required; [SimpleTermType]

◦ href required; [SimpleTermType]

◦ href required; [SimpleTermType]

■ SupportedExpressions optional, unbounded; [TermType]

■ Name optional; [string]

■ Description optional; [string]

■ Term optional, unbounded; [TermType]

■ Name optional; [string]

■ Description optional; [string]

■ Term optional, unbounded; [TermType]

■ Name optional; [string]

■ Description optional; [string]

■ Term optional, unbounded; [TermType] ... is recursive

◦ href required; [SimpleTermType]

◦ href required; [SimpleTermType]

◦ href required; [SimpleTermType]

■ ServiceID optional, unbounded; [anyURI]

◦ mpqfID required; [anyURI]

Output:

[GetServiceFeaturesResponse]

■ OutputCapabilities [MpegQueryType]

Contains a list of available service capability descriptions or a system message in case of an error. If no

service is available or matches the given capabilities, then an empty Output element is returned.

[Choice]

■ Query[Choice]

■ Management[Choice]

■ Output [OutputManagementType]

[Choice]

■ AvailableCapability optional, unbounded; [AvailableCapabilityType]

■ SystemMessage optional; [SystemMessageType][Choice]

■ Status unbounded; [InformationType]

■ Code [positiveInteger]

■ Description [string]

■ Warning unbounded; [InformationType]

■ Code [positiveInteger]

■ Description [string]

■ Exception unbounded; [InformationType]

■ Code [positiveInteger]

■ Description [string]

◦ mpqfID required; [anyURI]

-----------------------------------------------------------------------------------------------------------------------------------------------

4. RegisterDatabase

Description

Allows capability descriptions to be set.

SOAP action:

http://www.onvif.org/federatedsearch/wsdl/RegisterDatabase

Input:

[RegisterDatabase]

■ DatabaseFeaturesSupported unbounded; [RegisterDatabase]

Describes a predefined set of features supported by the database registered.

Output:

[RegisterDatabaseResponse]

-----------------------------------------------------------------------------------------------------------------------------------------------

5. Search

Description

Issuing a query including conditions and requested output structuring.

SOAP action:

http://www.onvif.org/federatedsearch/wsdl/Search

Input:

[Search]

■ InputQuery [MpegQueryType]

Container for describing a query request containing a set of conditions and/or the specification of the

structure and content of the output query format and a declaration part.

[Choice]

■ Query[Choice]

■ Input [InputQueryType]

■ QFDeclaration optional; [QFDeclarationType]

■ DeclaredField optional, unbounded; [DeclaredFieldType]

■ Resource optional, unbounded; [ResourceType]

◦ resourceID required; [ID]

■ OutputDescription optional; [OutputDescriptionType]

■ ReqField optional, unbounded; [FieldType]

■ ReqAggregateID optional, unbounded; [IDREF]

■ GroupBy optional;

■ GroupByField unbounded; [FieldType]

■ Aggregate optional, unbounded; [AggregateExpressionType]

■ SortBy optional, unbounded; [AbstractSortByType]

◦ order required; enum { 'ascending', 'descending' }

◦ maxPageEntries optional; [positiveInteger]

◦ maxItemCount optional;[positiveInteger]

◦ freeTextUse optional; [boolean]

◦ thumbnailUse optional; [boolean]

◦ mediaResourceUse optional; [boolean]

◦ outputNameSpace optional; [anyURI]

◦ distinct optional; [boolean]

■ QueryCondition optional; [QueryConditionType]

■ EvaluationPath optional; [xPathType]

■ TargetMediaType optional, unbounded; [mimeType]

[Choice]

■ Join [JoinType]

■ From

■ EvaluationPath optional; [xPathType]

■ TargetMediaType optional, unbounded; [mimeType]

■ Condition [BooleanExpressionType]

■ preferenceValue optional; [zeroToOneType]

■ thresholdValue optional; [zeroToOneType]

■ id required; [ID]

■ JoinCondition [BooleanExpressionType]

■ preferenceValue optional; [zeroToOneType]

■ thresholdValue optional; [zeroToOneType]

■ Condition [BooleanExpressionType]

■ preferenceValue optional; [zeroToOneType]

■ thresholdValue optional; [zeroToOneType]

■ ServiceSelection optional; [ServiceSelectionType]

■ ServiceID unbounded; [anyURI]

◦ previousAnswerID optional; [anyURI]

◦ immediateResponse optional; [boolean]

◦ timeout optional; [duration]

◦ mpqfID required; [anyURI]

Output:

[SearchResponse]

■ OutputQuery [MpegQueryType]

Container for all the results from a responder to a requester. It may contain in addition messages such as

error and exception.

[Choice]

■ Query[Choice]

■ Output [OutputQueryType]

■ GlobalComment optional; [string]

■ ResultItem optional, unbounded; [ResultItemType]

■ SystemMessage optional; [SystemMessageType][Choice]

■ Status unbounded; [InformationType]

■ Code [positiveInteger]

■ Description [string]

■ Warning unbounded; [InformationType]

■ Code [positiveInteger]

■ Description [string]

■ Exception unbounded; [InformationType]

■ Code [positiveInteger]

■ Description [string]

◦ currPage [positiveInteger]

◦ totalPages [positiveInteger]

◦ expirationDate optional; [dateTime]

◦ mpqfID required; [anyURI]

-----------------------------------------------------------------------------------------------------------------------------------------------

This informative document is based on the ONVIF Core Specification - Copyright ONVIF.